gchecky.model.bye_t

Package gchecky :: Module model :: Class bye_t |
[hide private]
[frames] | no frames]

# Class bye_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    bye_t

Represents a response that indicates that Google correctly received a <hello> request.

    >>> test_document(
    ...     bye_t(serial_number="7315dacf-3a2e-80d5-aa36-8345cb54c143")
    ... ,
    ...     '''
    ...     <bye xmlns="http://checkout.google.com/schema/2"
    ...           serial-number="7315dacf-3a2e-80d5-aa36-8345cb54c143" />
    ...     '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``bye``'`` The document's unique xml tag name.
| serial_number = `ID:PATH(@serial-number):REQ`
| _fields = ``{``'``serial_number``'``:` ID:PATH(@serial-number):REQ`}`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`